==> ugene_1.31.1.1+dfsg+rb2.orig.tar.xz: ugene-1.31.1.1+dfsg+rb2/src/plugins/test_runner/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
<context>
    <name>ExcludeReasonDialog</name>
    <message>
        <location filename="../src/ExcludeReasonDialog.ui" line="20"/>
        <source>exclude reason</source>
        <translation>Exclude reason</translation>
    </message>
    <message>
        <location filename="../src/ExcludeReasonDialog.ui" line="35"/>
        <source>Set exclude reason</source>
        <translation>Set exclude reason</translation>
    </message>
</context>
<context>
    <name>ExcludeResaonDialog</name>
    <message>
        <source>exclude reason</source>
        <translation type="vanished">Exclude reason</translation>
    </message>
    <message>
        <source>Set exclude reason</source>
        <translation type="vanished">Set exclude reason</translation>
    </message>
</context>
<context>
    <name>Reporter</name>
    <message>
        <location filename="../src/Reporter.ui" line="13"/>
        <source>utf_reporter_title</source>
        <translation>Reports</translation>
    </message>
    <message>
        <location filename="../src/Reporter.ui" line="27"/>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
</context>
<context>
    <name>TestView</name>
    <message>
        <location filename="../src/TestView.ui" line="14"/>
        <source>utf_view_title</source>
        <translation>Test runner</translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="28"/>
        <source>testColumn</source>
        <translation>Tests</translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="33"/>
        <source>stateColumn</source>
        <translation>State</translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="56"/>
        <source>info_label</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="94"/>
        <source>Save test</source>
        <translation>Save test</translation>
    </message>
</context>
<context>
    <name>U2::TestRunnerPlugin</name>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="52"/>
        <source>test_runner_plug_name</source>
        <translation>Test runner</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="52"/>
        <source>test_runner_desc</source>
        <translation>Test runner allows to run and manage tests suites and individual tests for Unipro UGENE. Enabled if environment variable UGENE_DEV is set</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="96"/>
        <location filename="../src/TestRunnerPlugin.cpp" line="107"/>
        <source>Can&apos;t load suite %1</source>
        <translation>Can&apos;t load suite %1</translation>
    </message>
</context>
<context>
    <name>U2::TestRunnerService</name>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="142"/>
        <location filename="../src/TestRunnerPlugin.cpp" line="178"/>
        <source>Test runner</source>
        <translation>Test runner</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="142"/>
        <source>Service to support UGENE embedded testing</source>
        <translation>Service to support UGENE embedded testing</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="293"/>
        <source>Error reading test suite from %1. Error: %2</source>
        <translation>Error reading test suite from %1. Error: %2</translation>
    </message>
</context>
<context>
    <name>U2::TestViewController</name>
    <message>
        <location filename="../src/TestViewController.cpp" line="438"/>
        <location filename="../src/TestViewController.cpp" line="478"/>
        <location filename="../src/TestViewController.cpp" line="788"/>
        <location filename="../src/TestViewController.cpp" line="808"/>
        <source>error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="943"/>
        <source>info</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="950"/>
        <source>env_mb_title</source>
        <translation>Environment variables</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1163"/>
        <source>passed</source>
        <translation>Passed</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1166"/>
        <source>failed</source>
        <translation>Failed</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1168"/>
        <source>not_run</source>
        <translation>Not run</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1202"/>
        <source>state: </source>
        <translation>State:</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1204"/>
        <source>fail_desc: </source>
        <translation>Fail reason:</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1207"/>
        <source>source_file:</source>
        <translation>Test file:</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="71"/>
        <source>Test runner</source>
        <translation>Test runner</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="84"/>
        <source>Add suite</source>
        <translation>Add suite</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="88"/>
        <source>Remove suite</source>
        <translation>Remove suite</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="92"/>
        <source>Run all tests</source>
        <translation>Run all tests</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="96"/>
        <source>Run selected</source>
        <translation>Run selected</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="102"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Setup environment</source>
        <translation type="obsolete">Setup environment</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="106"/>
        <source>Set environment</source>
        <translation>Выбрать окружение</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="110"/>
        <source>Generate report</source>
        <translation>Generate report</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="114"/>
        <source>Reload suites</source>
        <translation>Reload suites</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="119"/>
        <source>Select All</source>
        <translation>Select All</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="125"/>
        <source>Set Tests Enabled</source>
        <translation>Set Tests Enabled</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="131"/>
        <source>Set Tests Disabled</source>
        <translation>Set Tests Disabled</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="137"/>
        <source>Change Tests Excluded State</source>
        <translation>Change Tests Excluded State</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="141"/>
        <source>Save Selected Suites</source>
        <translation>Save Selected Suites</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="438"/>
        <source>Error reading test suites: 

 %1</source>
        <translation>Error reading test suites: 

 %1</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="453"/>
        <source>Select test suite file</source>
        <translation>Select test suite file</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="478"/>
        <source>Error reading test suite: %1</source>
        <translation>Error reading test suite: %1</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="788"/>
        <location filename="../src/TestViewController.cpp" line="808"/>
        <source>Not all environment variables set</source>
        <translation>Not all environment variables set</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="943"/>
        <source>No environment variables found</source>
        <translation>No environment variables found</translation>
    </message>
</context>
<context>
    <name>U2::TestViewReporter</name>
    <message>
        <location filename="../src/TestViewReporter.cpp" line="50"/>
        <source>save</source>
        <translation>Save report</translation>
    </message>
    <message>
        <location filename="../src/TestViewReporter.cpp" line="458"/>
        <source>select_save_path</source>
        <translation>Select file to save report</translation>
    </message>
    <message>
        <location filename="../src/TestViewReporter.cpp" line="458"/>
        <source>*.html</source>
        <translation>*.html</translation>
    </message>
</context>
</TS>

==> ugene_33.0+dfsg.orig.tar.xz: ugene-33.0/src/plugins/test_runner/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
<context>
    <name>ExcludeReasonDialog</name>
    <message>
        <location filename="../src/ExcludeReasonDialog.ui" line="20"/>
        <source>exclude reason</source>
        <translation>Exclude reason</translation>
    </message>
    <message>
        <location filename="../src/ExcludeReasonDialog.ui" line="35"/>
        <source>Set exclude reason</source>
        <translation>Set exclude reason</translation>
    </message>
</context>
<context>
    <name>ExcludeResaonDialog</name>
    <message>
        <source>exclude reason</source>
        <translation type="vanished">Exclude reason</translation>
    </message>
    <message>
        <source>Set exclude reason</source>
        <translation type="vanished">Set exclude reason</translation>
    </message>
</context>
<context>
    <name>Reporter</name>
    <message>
        <location filename="../src/Reporter.ui" line="14"/>
        <source>utf_reporter_title</source>
        <translation>Reports</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
</context>
<context>
    <name>TestView</name>
    <message>
        <source>utf_view_title</source>
        <translation type="vanished">Test runner</translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="14"/>
        <source>Test Runner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="28"/>
        <source>testColumn</source>
        <translation>Tests</translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="33"/>
        <source>stateColumn</source>
        <translation>State</translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="65"/>
        <source>info_label</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../src/TestView.ui" line="112"/>
        <source>Save test</source>
        <translation>Save test</translation>
    </message>
</context>
<context>
    <name>U2::TestRunnerPlugin</name>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="52"/>
        <source>test_runner_plug_name</source>
        <translation>Test runner</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="52"/>
        <source>test_runner_desc</source>
        <translation>Test runner allows one to run and manage tests suites and individual tests for Unipro UGENE. Enabled if environment variable UGENE_DEV is set</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="96"/>
        <location filename="../src/TestRunnerPlugin.cpp" line="107"/>
        <source>Can&apos;t load suite %1</source>
        <translation>Can&apos;t load suite %1</translation>
    </message>
</context>
<context>
    <name>U2::TestRunnerService</name>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="142"/>
        <location filename="../src/TestRunnerPlugin.cpp" line="178"/>
        <source>Test runner</source>
        <translation>Test runner</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="142"/>
        <source>Service to support UGENE embedded testing</source>
        <translation>Service to support UGENE embedded testing</translation>
    </message>
    <message>
        <location filename="../src/TestRunnerPlugin.cpp" line="296"/>
        <source>Error reading test suite from %1. Error: %2</source>
        <translation>Error reading test suite from %1. Error: %2</translation>
    </message>
</context>
<context>
    <name>U2::TestViewController</name>
    <message>
        <location filename="../src/TestViewController.cpp" line="438"/>
        <location filename="../src/TestViewController.cpp" line="478"/>
        <location filename="../src/TestViewController.cpp" line="788"/>
        <location filename="../src/TestViewController.cpp" line="808"/>
        <source>error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="943"/>
        <source>info</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="950"/>
        <source>env_mb_title</source>
        <translation>Environment variables</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1163"/>
        <source>passed</source>
        <translation>Passed</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1166"/>
        <source>failed</source>
        <translation>Failed</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1168"/>
        <source>not_run</source>
        <translation>Not run</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1202"/>
        <source>state: </source>
        <translation>State:</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1204"/>
        <source>fail_desc: </source>
        <translation>Fail reason:</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="1207"/>
        <source>source_file:</source>
        <translation>Test file:</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="71"/>
        <source>Test runner</source>
        <translation>Test runner</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="84"/>
        <source>Add suite</source>
        <translation>Add suite</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="88"/>
        <source>Remove suite</source>
        <translation>Remove suite</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="92"/>
        <source>Run all tests</source>
        <translation>Run all tests</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="96"/>
        <source>Run selected</source>
        <translation>Run selected</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="102"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Setup environment</source>
        <translation type="obsolete">Setup environment</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="106"/>
        <source>Set environment</source>
        <translation>Выбрать окружение</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="110"/>
        <source>Generate report</source>
        <translation>Generate report</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="114"/>
        <source>Reload suites</source>
        <translation>Reload suites</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="119"/>
        <source>Select All</source>
        <translation>Select All</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="125"/>
        <source>Set Tests Enabled</source>
        <translation>Set Tests Enabled</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="131"/>
        <source>Set Tests Disabled</source>
        <translation>Set Tests Disabled</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="137"/>
        <source>Change Tests Excluded State</source>
        <translation>Change Tests Excluded State</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="141"/>
        <source>Save Selected Suites</source>
        <translation>Save Selected Suites</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="438"/>
        <source>Error reading test suites: 

 %1</source>
        <translation>Error reading test suites: 

 %1</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="453"/>
        <source>Select test suite file</source>
        <translation>Select test suite file</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="478"/>
        <source>Error reading test suite: %1</source>
        <translation>Error reading test suite: %1</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="788"/>
        <location filename="../src/TestViewController.cpp" line="808"/>
        <source>Not all environment variables set</source>
        <translation>Not all environment variables set</translation>
    </message>
    <message>
        <location filename="../src/TestViewController.cpp" line="943"/>
        <source>No environment variables found</source>
        <translation>No environment variables found</translation>
    </message>
</context>
<context>
    <name>U2::TestViewReporter</name>
    <message>
        <location filename="../src/TestViewReporter.cpp" line="52"/>
        <source>save</source>
        <translation>Save report</translation>
    </message>
    <message>
        <location filename="../src/TestViewReporter.cpp" line="460"/>
        <source>select_save_path</source>
        <translation>Select file to save report</translation>
    </message>
    <message>
        <location filename="../src/TestViewReporter.cpp" line="460"/>
        <source>*.html</source>
        <translation>*.html</translation>
    </message>
</context>
</TS>
